classdef ContinuerManager
    %CONTINUERMANAGER Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
            continuer
    end
    
    methods
        
        function obj = ContinuerManager()
            obj.continuer = @cont_new; 
        end
        
        function cont(obj , session , direction , launchdriverwindow)
            if (nargin < 4), launchdriverwindow = true; end
            curve = session.currentcurve;
            
            session.getContData().setBackwards(~direction);
            curvetype = curve.getCurveType();
            
            
            
            startdata = session.getStartData();

            %do sanity check
            reqparam = curvetype.getReqNrFreeParams();
            if (startdata.getNrFreeParams() ~= reqparam)
                errordlg([ num2str(reqparam) ' active parameter are needed for a ' curvetype.getLabel() '-curve continuation'], 'Error in number of active parameters');
                return
            end
            
            bm = session.getBranchManager();
            if (~ bm.validSelectionMade())
                errordlg('No branch selected' , 'Error');
                return                
            end
             
            % end sanity check
            if (curve.hasFile())
                %anonymize
                session.currentcurve = session.curvemanager.getEmptyCurveFrom(curve.getLabel());
                curve = session.currentcurve;
            end
            
            x0 = startdata.getCoordinateValues();
            par = startdata.getParameterValues();
            systemhandle = session.getSystem().getFunctionHandle();

            
            curve.loadGlobalVars(curvetype);
            
            nIterationOld = startdata.getSetting('iterationN');
            nIteration = bm.getNewIterationN(  nIterationOld );
            startdata.setSetting('iterationN' , nIteration);
            
            
            
            [x0 , v0] = bm.performInit(session, curve, x0 , par, systemhandle, nIteration);

            if isempty(x0)
               disp('Init failed');
               startdata.setSetting('iterationN' , nIterationOld);
               return;
            end
            
            
            session.lock();
            
            if (launchdriverwindow)
                DriverPanel(session);
            end            
            
            [x , v , s , h , f] = ...
                obj.continuer(    curvetype.getCurveDefinition() ...
                     , x0 , v0 , ...
                  session.optioninterface  );
              
              if ~isempty(x)
                  curve.setData(x,v,s,h,f);
                  
                  curve.saveGlobalVars(curvetype);
                  session.getCurveManager().name(startdata , session.getContData());
                  session.getCurveManager().save(curve);
                  session.notify('stateChanged');
              end
              
            session.unlock();
            
        end
        
        function cont_extend(obj, session, launchdriverwindow)  %geen mogelijk voor nieuwe opties.. fix ?
            if (nargin < 3), launchdriverwindow = true; end
            
	    c = session.currentcurve;
            curvetype = c.getCurveType();
            
            session.lock();
            
            if (launchdriverwindow)
                DriverPanel(session);
            end
            
            c.loadGlobalVars(curvetype);
             [x , v , s , h , f]  = ...
                obj.continuer( c.x , c.v , c.s , c.h, c.f , c.globals.cds); 
             
            if ~isempty(x)
                  c.setData(x,v,s,h,f);
                  c.saveGlobalVars(curvetype);
                  %FIXME: extend savebug
                  session.getCurveManager().save(c);
		  %session.notify('stateChanged');
            end 
            
            session.unlock();
        end
        
        function orbit(obj , session, pointplot)
        global sOutput
            launchdriverwindow = true; 
            
            
            startdata = session.getStartData();
            contdata = session.getContData();
            
            curve = session.currentcurve;
            
             if (curve.hasFile())
                 %anonymize
                 session.currentcurve = session.curvemanager.getEmptyCurveFrom(curve.getLabel());
                 curve = session.currentcurve;
             end
                                 
            
            %force correct options:
                startdata.setTrajectOptions();
            %end
            %set up sessionOutput:
            
            x0 = startdata.getCoordinateValues();
            x_len = length(x0);

            P0 = startdata.getParameterValues();
            par = num2cell(startdata.getParameterValues());
            

            
            iterationN = startdata.getSetting('iterationN');
            
            systemhandle = session.getSystem().getFunctionHandle();
            handles = feval(systemhandle);
            fun_eval = handles{2};
            
            npoints = contdata.getStopData('MaxNumPoints');
            
            report = sOutput.getReportFunction();
            sOutput.setStatus('Computing ...');
            sOutput.setPauseAlways();            
            
            
            
            if (~isempty(pointplot))
                bool = pointplot.startup();
                if (~bool)
                    report('plot not valid');
                    return;
                end
            end
            if (launchdriverwindow)
                DriverPanel(session);
                drawnow;
            end            
            
            x = zeros(x_len,npoints);
            
            x(:,1) = x0;
            s = struct();
            
            s(1).label = '00';
            s(1).index = 1;
            s(1).data = [];
            s(1).msg = 'This is the first point of the curve';
            s_.label = '  ';
            s_.index = 1;
            s_.msg = 'Point Calculated';
            
            
            sOutput.output(0,x, s ,[] , [] ,1);
            report([ sprintf('x_(%d) = ', 1) SessionOutput.vector2str(x(:,1)) '\n' ]);
            if (~isempty(pointplot)), pointplot.outputPoint(x, [] , [], 1 , {} , SessionOutput.vector2str(x(:,1))) ; end
            
            drawnow;
            doStop = sOutput.checkPauseResumeStop(s(1).index , s_.msg ,1);
            if doStop~=0, npoints = 1;end  %npoints = i ---> end of mainloop
                    
                    
            i = 2;
            while (i <= npoints)
                x(:,i) =  evalf(fun_eval, iterationN, x(:,i-1), par);


                    sOutput.output(0,x, s ,[] , [] ,i);
                    if (~isempty(pointplot))
                        pointplot.outputPoint(x, [] , [], i , {} , SessionOutput.vector2str(x(:,i))); 
                        pointplot.output(session, x, s(1) , [] , [] , i);
                    end
                    report([ sprintf('x_(%d) = ', i) SessionOutput.vector2str(x(:,i)) '\n' ]); 
                    drawnow;
                    doStop = sOutput.checkPauseResumeStop(s(1).index , s_.msg ,i);
                    if doStop~=0, npoints = i;end  %npoints = i ---> end of mainloop

                
                i=i+1;
            end
            
            report('npoints curve = %d\n', npoints);
            sOutput.endRun();
            x = x(:,1:npoints);
            
            
            s(2).label = '99';
            s(2).index = npoints;
            s(2).data = [];
            s(2).msg = 'This is the last point on the curve';
            
            global ods cds
            ods.P0 = P0;
            cds.options = contmrg( contset , session.optioninterface);
            
            
             curve.setData(x,[],s,zeros(length(x0) , npoints),[]);
             curve.saveGlobalVars(curve.getCurveType());
             session.getCurveManager().name(startdata , session.getContData());
             session.getCurveManager().save(curve);
             session.notify('stateChanged');
        end
    end
    
    
    
    
end


function X = evalf(fhandle , iter , X , param)
    for i = 1:iter
       X = feval(fhandle,0, X , param{:}); 
    end
end



