function cli = gui(varargin)
global session 

guipath = which(mfilename);
path = [cutpath(cutpath(guipath)) '/'];


systempath = [path 'Systems/'];
setupPath(path);

DEBUG = ~ismember('nodebug' , varargin);
if (DEBUG)
   Console();
    printc(mfilename , ['Path =  ' path]);
end

session = Session(systempath);




mwindowhandle = session.getWindowManager().createMainWindow();


handlelist = [];

handle = uimenu(mwindowhandle , 'Label' , 'System');
handlelist(end+1) = handle;
uimenu(handle , 'Label' , 'Systembrowser' , 'Callback', @(o,e) MainPanel.browsesystem(session,systempath)  );
MenuItem(handle, @() CommanderModel.manageCurrentDiagram(session), 'Organize Diagrams' , session , @() ~isempty(session.system) , 'stateChanged');

uimenu(handle, 'Label' , 'Exit' , 'Callback' , @(o,e)  closemainwindow(session));

handle = uimenu(mwindowhandle , 'Label' , 'Type');
handlelist(end+1) = handle;

SelectBranchMenu(handle,'uimenu' ,  session , session.getBranchManager());

SelectPointsMenu(handle , StaticPointType() , session);


handle = uimenu(mwindowhandle , 'Label' , 'Setting');
handlelist(end+1) = handle;



WindowLaunchButton(handle , session.getWindowManager() , 'uimenu', ...
       @(fhandle) ContinuerPanel(fhandle,session.continuedata), 'continuer');


WindowLaunchButton(handle , session.getWindowManager() , 'uimenu', ...
       @(fhandle) StarterPanel(fhandle,session.starterdata), 'starter');   
   

handle = uimenu(mwindowhandle , 'Label' , 'Output');
handlelist(end+1) = handle;

gm = uimenu(handle , 'Label' , 'Graphic');
SyncHandles(session, gm , @() session.numericAllowed());
uimenu(gm, 'Label' , '2D plot' , 'Callback' , @(o,e) session.getPlotManager().create2Dplot(session));
uimenu(gm, 'Label' , '3D plot' , 'Callback' , @(o,e) session.getPlotManager().create3Dplot(session));
   
WindowLaunchButton(handle , session.getWindowManager() , 'uimenu', ...
       @(fhandle) numericWindowLaunch(session , fhandle) , 'numeric');   

   
   



handle = uimenu(mwindowhandle , 'Label' , 'Compute');
handlelist(end+1) = handle;

MenuItem(handle, @() doContinue(session) , @() 'Forward' , session , @() session.performContinueAllowed() , 'stateChanged');
MenuItem(handle, @() doContinueBackward(session) , @() 'Backward' , session , @() session.performContinueAllowed() , 'stateChanged');
MenuItem(handle ,@() doExtend(session)  , @() 'Extend' , session, @() session.performExtendAllowed(), 'stateChanged');

handle = uimenu(mwindowhandle , 'Label' , 'Options');
ConfigMenu(handle, session.configmanager);
handlelist(end+1) = handle;


if(DEBUG)
    handle = uimenu(mwindowhandle , 'Label' , 'Debug');
    SelectPlotMenu( handle , session );
    uimenu(handle , 'Label' , 'Display OptionsStruct' , 'Callback', @(o,e) doDisplay(session.optioninterface)  );
    uimenu(handle , 'Label' , 'Console' , 'Callback' , @(o,e) Console(session) );
    SelectSwitchMenu( handle , session.sessiondata);
    uimenu(handle , 'Label' , 'session unlock' , 'Callback' , @(o,e) session.unlock());
    
    
    uimenu(handle , 'Label' , 'Set TrajectoryMode' , 'Callback' , @(o,e) setTrajMode(session));
    uimenu(handle , 'Label' , 'Calc Trajectory' , 'Callback' , @(o,e) doTraj(session));
    uimenu(handle , 'Label' , 'Calc Trajectory + plot2d' , 'Callback' , @(o,e) doTraj_plot2d(session));
    
    %handlelist(end+1) = handle;
end

MainPanel( mwindowhandle , session );

set(mwindowhandle , 'Visible' , 'on' );

SyncHandles(session, handlelist, @() session.isUnlocked());

if (nargout == 1)
   cli = CommandLineInterface(session);  
end

if (DEBUG)
%    Console(session);
	Console.monitorEvents(session , 'recursive');
% 	Console.monitorEvents(session.continuedata);
% 	Console.monitorEvents(session.starterdata);
% 	Console.monitorEvents(session.numericdata);
% 	Console.monitorEvents(session.windowmanager);
% 	Console.monitorEvents(session.branchmanager);
% 	Console.monitorEvents(session.plotmanager);
end



end

function doContinue(session)
global sOutput
    cm = ContinuerManager();
    
    sOutput = SessionOutput(session , session.numericdata );
    
    cm.cont(session , 1); %FORWARD
end

function doContinueBackward(session)
global sOutput
    cm = ContinuerManager();
    
    sOutput = SessionOutput(session , session.numericdata );
    
    cm.cont(session , 0); %BACKWARD
end

function doExtend(session)
global sOutput
    cm = ContinuerManager();
    sOutput = SessionOutput(session , session.numericdata );
    
    cm.cont_extend( session );
end

function numericWindowLaunch(session , fhandle)
  
    set(fhandle , 'CloseRequestFcn'  , @(o,e) numericclose(session)); 
    NumericPanel(fhandle,session.numericdata , true);
  
end

function numericclose(session)
    if (session.isUnlocked())
        session.windowmanager.closeWindow('numeric');
    end
end
function setTrajMode(session)
    session.setPointType( PointType('P','Point') );
    session.setCurveType( CurveType_O());
end

function doTraj(session)
global sOutput    
    cm = ContinuerManager();
    sOutput = SessionOutput(session , session.numericdata );
    cm.orbit(session, []);
end

function doTraj_plot2d(session)
global sOutput    
    cm = ContinuerManager();
    sOutput = SessionOutput(session , session.numericdata );
    cm.orbit(session, TrajectPlot(session, 2));
end

function closemainwindow(session)
	session.getWindowManager().closeAllWindows();
end

